@@ -140,7 +140,7 @@ play_manual_tour <- function(basis = NULL,
                              data,
                              manip_var,
                              theta = NULL,
-                             phi_min = 0L,
+                             phi_min = 0,
                              phi_max = .5 * pi,
                              angle = .05,
                              render_type = render_plotly,
@@ -217,9 +217,9 @@ play_manual_tour <- function(basis = NULL,
 view_frame <- function(basis = NULL,
                        data = NULL,
                        manip_var = NULL,
-                       theta = 0L,
-                       phi = 0L,
-                       basis_label = abbreviate(row.names(basis), 3L),
+                       theta = 0,
+                       phi = 0,
+                       basis_label = abbreviate(row.names(basis), 3),
                        rescale_data = FALSE,
                        ...){
   lifecycle::deprecate_warn("0.3.0", "view_frame()", "spinifex::ggtour()")
@@ -311,11 +311,11 @@ oblique_basis <- function(...) {
 view_manip_space <- function(basis,
                              manip_var,
                              tilt = .1 * pi,
-                             basis_label = abbreviate(row.names(basis), 3L),
+                             basis_label = abbreviate(row.names(basis), 3),
                              manip_col = "blue",
                              manip_sp_col = "red",
-                             line_size = 1L,
-                             text_size = 5L,
+                             line_size = 1,
+                             text_size = 5,
                              ggproto = list(
                                theme_spinifex()
                              )
